==> blesta-5.10.2.zip: blesta/plugins/order/views/templates/ajax/language/tr_tr/config.php <==
<?php
/**
 * Config
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Config.index.term_years'] = '1$s yıl';
$lang['Config.index.term_year'] = '1$s yıl';
$lang['Config.index.term_months'] = '1$s ay';
$lang['Config.index.term_month'] = '1$s ay';
$lang['Config.index.term_weeks'] = '1$s hafta';
$lang['Config.index.term_week'] = '1$s hafta';
$lang['Config.index.term_days'] = '1$s gün';
$lang['Config.index.term_day'] = '1$s gün';
$lang['Config.index.continue_btn'] = 'Devam et';
$lang['Config.index.addons_notes'] = 'Seçilen tüm eklentiler bir sonraki adımda yapılandırılacaktır.';
$lang['Config.index.header_addons'] = 'Mevcut Eklentiler';
$lang['Config.index.header_module'] = 'Yapılandırılabilir Seçenekler';
$lang['Config.index.header_term'] = 'Süre ve Fiyat';
$lang['Config.index.config_notes'] = 'İstediğiniz seçenekleri seçin ve ödeme işlemine devam edin.';
$lang['Config.index.text_free_domain'] = '1$s veya daha yüksek bir fiyatlandırma seçeneği, bir sonraki adımda ücretsiz alan adı almaya hak kazandırır.';
$lang['Config.index.text_free_domain_next_step'] = 'Bir sonraki adımda, bu alan adını ücretsiz almak için minimum %1$\'lık bir süre için uygun bir öğe seçin.';
$lang['Config.index.text_free_domain_next_step_limited'] = 'Bir sonraki adımda, bu alan adını %2$s süreyle ücretsiz almak için minimum %1$s süreyle uygun bir öğe seçin.';
$lang['Config.index.header_configure_service'] = '1$s\'yi yapılandırın';
$lang['Config.index.header_configuration'] = 'Konfigürasyon';

==> blesta-5.11.4.zip: blesta/plugins/order/views/templates/ajax/language/tr_tr/config.php <==
<?php
/**
 * Config
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Config.index.continue_btn'] = 'Devam et';
$lang['Config.index.addons_notes'] = 'Seçilen tüm eklentiler bir sonraki adımda yapılandırılacaktır.';
$lang['Config.index.header_addons'] = 'Mevcut Eklentiler';
$lang['Config.index.header_module'] = 'Yapılandırılabilir Seçenekler';
$lang['Config.index.header_term'] = 'Süre ve Fiyat';
$lang['Config.index.config_notes'] = 'İstediğiniz seçenekleri seçin ve ödeme işlemine devam edin.';
$lang['Config.index.text_free_domain_next_step'] = 'Bir sonraki adımda, bu alan adını ücretsiz almak için minimum %1$\'lık bir süre için uygun bir öğe seçin.';
$lang['Config.index.text_free_domain_next_step_limited'] = 'Bir sonraki adımda, bu alan adını %2$s süreyle ücretsiz almak için minimum %1$s süreyle uygun bir öğe seçin.';
$lang['Config.index.header_configuration'] = 'Konfigürasyon';
$lang['Config.index.term_years'] = '%1$s yıl';
$lang['Config.index.term_year'] = '%1$s yıl';
$lang['Config.index.term_months'] = '%1$s ay';
$lang['Config.index.term_month'] = '%1$s ay';
$lang['Config.index.term_weeks'] = '%1$s haftalar';
$lang['Config.index.term_week'] = '%1$s haftası';
$lang['Config.index.term_days'] = '%1$s gün';
$lang['Config.index.term_day'] = '%1$s günü';
$lang['Config.index.text_free_domain'] = 'Fiyatlandırma seçeneğinin %1$s veya daha yüksek olması, bir sonraki adımda ücretsiz alan adı almanızı sağlar.';
$lang['Config.index.header_configure_service'] = 'Configure %1$s';
